/*|
 *|   PNGLOGO4.POV -- scene file for POV-Ray 2.2
 *|   Copyright (c) 1995 by Oliver Fromme -- All Rights Reserved
 *|
 *|   Oliver Fromme, Leibnizstr. 18-61, 38678 Clausthal, Germany
 *|   Internet/Usenet email:  fromme@rz.tu-clausthal.de
 *|   WWW:  http://www.rz.tu-clausthal.de/~inof/Welcome.html
 *|
 *|   May be used freely without charge for any purpose.
 *|   This copyright notice may not be removed or modified.
 *|
 */

/*
 *   Rendering time for original image (POV-Ray 2.2.ibmicb):
 *      Pentium-90   1440x960   2:44:58
 *      with text backgound     3:23:01
 */

/*|
 *|   [Modifications by Greg Roelofs, 4 May 1995:  changed wood texture,
 *|    shuffled balls' colors, made some balls transparent, removed `!',
 *|    rotated/enlarged/clarified/fixed "PNG" word, changed aspect ratio
 *|    to 4:3]
 *|
 *|   Rendering time for modified image (POV-Ray 2.2 for Linux/X):
 *|      486-33       1024x768  12:30:38 (wallclock)
 *|                             12:16:35 (CPU)
 *|
 */

#version 3.5;

#include "colors.inc"
#include "shapes.inc"
#include "textures.inc"

// GRR 20020202:  black818:  added global_settings node with photons
global_settings {
   photons {
      count 20000
      autostop 0
      jitter .4
   }
}

// GRR 20000812:  white7d:  added background node
// GRR 20000813:  black7u:  changed background node to Black
// GRR 20200802:  black823:  changed background node to dark gray
//background { color White }
//background { color Black }
background { color rgb <0.1, 0.1, 0.1> }

//
//   +x:  right
//   +y:  out
//   +z:  up (upper rows of image)
//
camera {
   up <0, 1, 0>
   right <1.333, 0, 0> // aspect ratio 4:3 for typical backgrounds
   //right <1.778, 0, 0>   // GRR 20200801:  aspect ratio 16:9 for more modern displays
   location <0.05, -4, -27.5>
   direction <0, 0, 1.5>
   look_at <0, -0.4, 0>
}

// GRR 20010828:  trunc7w:  shifted main light up (more over letters:  -28)
// GRR 20010828:  trunc7x:  shifted main light source up some more (-25)
// GRR 20010828:  trunc7y:  shifted main light source left, up some (-2, -24)
// GRR 20010828:  trunc7z:  shifted main light source back right (-1, -24)
light_source {<-1, 15, -24> color White}
light_source {<-1, 15, -24> color White}
light_source {<-1, 15, -24> color White}

light_source {<-30, 15, 15> color White}
light_source {< 30, 15, 15> color White}
light_source {<-30, 0, 0> color White}
light_source {< 30, 0, 0> color White}

light_source {< 0, -15, 30> color White}

// GRR 20000812:  white7h:  added transparency to Red; dropped Green intensity
// GRR 20000813:  white7i:  dropped Red and Green intensity further
// GRR 20000813:  white7j:  raised Red intensity a bit
// GRR 20000813:  white7p:  boosted Red transparency and green level
// GRR 20000813:  white7q:  reduced Red green level again
//#declare MyCopper = color rgb <0.95, 0.33, 0.10> ;
#declare grrCopper = color rgb <0.95, 0.4, 0.10> ;
#declare grrBlue = color rgb <0.2, 0.2, 0.7> ;
//#declare grrGreen = color rgbf <0.1, 0.8, 0.1, 0.6> ;
//#declare grrGreen = color rgbf <0.1, 0.65, 0.1, 0.6> ;
#declare grrGreen = color rgbf <0, 0.4, 0, 0.6> ;  // NO LONGER USED
//#declare grrRed = color rgb <0.8, 0.1, 0.1> ;
//#declare grrRed = color rgbf <0.8, 0.1, 0.1, 0.8> ;
//#declare grrRed = color rgbf <0.5, 0.1, 0.1, 0.7> ;
//#declare grrRed = color rgbf <0.65, 0.1, 0.1, 0.7> ;
//#declare grrRed = color rgbf <0.65, 0.25, 0.1, 0.9> ;
#declare grrRed = color rgbf <0.65, 0.1, 0.1, 0.9> ;
//#declare grrYellow = color rgbf <0.8, 0.8, 0.1, 0.6> ;
#declare grrYellow = color rgb <0.5, 0.5, 0.1> ;  // black826
// GRR 20000813:  white7s:  added grrPurple to replace grrGreen
// GRR 20000813:  white7t:  boosted red to 0.4
//#declare grrPurple = color rgbf <0.3, 0, 0.6, 0.6> ;
#declare grrPurple = color rgbf <0.4, 0, 0.6, 0.6> ;

// Textures for passes 1 - 7:

#declare P1_t = texture {pigment {Gold} finish {Metal}} ;
#declare P2_t = texture {pigment {grrCopper} finish {Metal}} ;
#declare P3_t = texture {pigment {grrBlue} finish {Metal}} ;
// GRR 20000813:  white7q:  changed finish/color to P7_t from white7n (purple)
// GRR 20000813:  white7r:  darkened purple 20%
//#declare P4_t = texture {Glass pigment {grrGreen} finish {Metal}} ;
#declare P4_t = texture {Glass pigment {grrPurple} finish {Metal}} ;	// 7s
//#declare P4_t_NOTUSED = texture {Glass
//         //pigment {color rgb <0.45, 0.1, 0.7> filter 0.8}	// 7q
//         pigment {color rgb <0.36, 0.08, 0.56> filter 0.8}	// 7r
//         finish {
//            Shiny
//            ambient 0
//            diffuse 0.2
//            reflection 0.55
//            ior 1.5		// triggers warning in 3.7 (should be part of interior{}, not texture{})
//         }
//      } ;

// GRR 20000813:  white7t:  changed to colortest10 values
// GRR 20000813:  white7u:  changed to colortest08 values
//#declare P5_t = texture {pigment {grrRed} finish {Metal}} ;
#declare P5_t = texture {
         //Glass
         pigment {color rgbf <0.65, 0.1, 0.2, 0.6>}
         finish {
            Shiny
            ambient 0 
            diffuse 0.4
            //reflection 0.25	// 7t
            reflection 0.35	// 7u
         }
      } ;

//#declare P6_t = texture {Glass pigment {grrYellow} finish {Metal}} ;
#declare P6_t = texture {pigment {grrYellow} finish {Metal}} ;  // black826

//#declare P7_t = texture {Glass pigment {Silver filter 0.8} finish {Metal}} ;
//#declare P7_t = texture {Mirror pigment {Silver}} ;
// GRR 20000812:  white7g:  changed from Silver to same material as "PNG"
// GRR 20000812:  white7h:  changed from blue-gray to dark(?) green
// GRR 20000813:  white7j:  changed from middle/pale green to dark purple
// GRR 20000813:  white7k:  lightened and de-transparentified purple slightly
// GRR 20000813:  white7m:  changed finish to Metal
// GRR 20000813:  white7n:  changed finish back, boosted reflection, lightened
// GRR 20000813:  white7o:  reduced red, boosted reflection more
// GRR 20000813:  white7p:  boosted transparency
// GRR 20000813:  white7q:  changed finish back to 7n, assigned to P4_t
// GRR 20010902:  black800:  changed transparency back to 7n
// GRR 20010902:  black801:  changed ambient from 0 to 0.5
// GRR 20010902:  black802:  changed reflection to 0.55, ambient to 0.7
// GRR 20010902:  black803:  changed reflection to 0.70; added specular/roughn.
// GRR 20010902:  black804:  changed ambient to 0.4, diffuse to 0.3
// GRR 20010902:  black805:  ambient = 0.7, diffuse = 0.2; added iridescence
// GRR 20010902:  black806:  reduced diffuse to 0.1 (irid too milky)
// GRR 20010902:  black807:  reduced ambient to 0.3 (irid too milky)
// GRR 20010902:  black808:  reduced irid amount to 0.15 (irid still too milky)
// GRR 20010902:  black809:  increased irid amount to 0.22
//#declare P7_t = texture {Glass
//         //pigment {color rgb <0.5, 0.55, 0.6> filter 0.925}	// 7g
//         //pigment {color rgb <0.3, 0.55, 0.3> filter 0.925}	// 7i, 7q
//         //pigment {color rgb <0.2, 0.05, 0.4> filter 0.925}	// 7j
//         //pigment {color rgb <0.45, 0.1, 0.7> filter 0.8}	// 7n
//         //pigment {color rgb <0.3, 0.1, 0.65> filter 0.8}	// 7o
//         //pigment {color rgb <0.3, 0.1, 0.65> filter 0.9}	// 7p
//         //pigment {color rgb <0.3, 0.55, 0.3> filter 0.8}	// 800
//         pigment {color rgb <0.3, 0.55, 0.3> filter 0.8}	// 804
//         //finish {Metal}
//         finish {
//            Shiny
//            //ambient 0.7 	// 805
//            ambient 0.3		// 807
//            //diffuse 0.2 	// 805
//            diffuse 0.1		// 806
//            reflection 0.70	// 803
//            specular 0.75	// 803
//            roughness 0.001	// 803
//            irid {		// 805
//               //0.35		// 805
//               //0.15		// 808
//               0.22		// 809
//               thickness .5
//               turbulence .5
//            }
//         }
//      } ;
// GRR 20200802:  black822:  restored clear glass from white7g
// GRR 20200802:  black824:  more green experiments
#declare P7_t = texture {Glass
         //pigment {color rgb <0.5, 0.55, 0.6> filter 0.925}	// 822-823
         //pigment {color rgb <0.1, 0.3, 0.1> filter 0.7}	// 824
         pigment {color rgb <0.1, 0.4, 0.1> filter 0.5}		// 825
         finish {
            Shiny
            ambient 0
            diffuse 0.2
            //reflection 0.3	// 822-824
            reflection 0.5	// 825
         }
      }

// GRR 20010902:  black801:  added "interior" with fade_*
// GRR 20010902:  black802:  changed fade_power to 1
#declare P7_i = interior {
         //ior 1.5		// 822, 823
         ior 2.5		// 824
         fade_distance 10	// 801
         //fade_power 2		// 801
         fade_power 1		// 802
      } ;

// Radius for passes 1 - 7:

#declare P1_r = 1.2 ;
#declare P2_r = 1.1 ;
#declare P3_r = 1.0 ;
#declare P4_r = 0.9 ;
#declare P5_r = 0.8 ;
#declare P6_r = 0.7 ;
#declare P7_r = 0.6 ;

/* for "missing" balls (0.0 causes floating exception):
#declare P1_r = 0.00001 ;
#declare P2_r = 0.00001 ;
#declare P3_r = 0.00001 ;
#declare P4_r = 0.00001 ;
#declare P5_r = 0.00001 ;
#declare P6_r = 0.00001 ;
#declare P7_r = 0.00001 ;
 */

// Depth of hollows in shelf:

#declare HDepth = 0.4 ;

// Y positions of centers of the beads:

#declare P1_y = P1_r - HDepth ;
#declare P2_y = P2_r - HDepth ;
#declare P3_y = P3_r - HDepth ;
#declare P4_y = P4_r - HDepth ;
#declare P5_y = P5_r - HDepth ;
#declare P6_y = P6_r - HDepth ;
#declare P7_y = P7_r - HDepth ;

// The first row of beads (passes 1, 2, 4 and 6):

#declare Beads_row1 =
   union {
      sphere {<-7, P1_y, 0>, P1_r texture {P1_t}} // pass 1
      sphere {< 1, P2_y, 0>, P2_r texture {P2_t}} // pass 2
      union { // pass 4
         sphere {<-3, P4_y, 0>, P4_r}      sphere {< 5, P4_y, 0>, P4_r}
         texture {P4_t}
      }
      union { // pass 6
         sphere {<-5, P6_y, 0>, P6_r}      sphere {<-1, P6_y, 0>, P6_r}
         sphere {< 3, P6_y, 0>, P6_r}      sphere {< 7, P6_y, 0>, P6_r}
         texture {P6_t}
      }
   } ;

// The second row of beads (pass 7, identical to rows 4, 6 and 8):

#declare Beads_row2 =
   union {
      sphere {<-7, P7_y, 0>, P7_r}      sphere {<-5, P7_y, 0>, P7_r}
      sphere {<-3, P7_y, 0>, P7_r}      sphere {<-1, P7_y, 0>, P7_r}
      sphere {< 1, P7_y, 0>, P7_r}      sphere {< 3, P7_y, 0>, P7_r}
      sphere {< 5, P7_y, 0>, P7_r}      sphere {< 7, P7_y, 0>, P7_r}
      texture {P7_t}
      interior {P7_i}	// 801
   } ;

// The third row of beads (passes 5 and 6, identical to row 7):

#declare Beads_row3 =
   union {
      union { // pass 5
         sphere {<-7, P5_y, 0>, P5_r}      sphere {<-3, P5_y, 0>, P5_r}
         sphere {< 1, P5_y, 0>, P5_r}      sphere {< 5, P5_y, 0>, P5_r}
         texture {P5_t}
         interior {		// 819
            ior 1.5		// was inside P5_t finish{} (old syntax)
         }
      }
      union { // pass 6
         sphere {<-5, P6_y, 0>, P6_r}      sphere {<-1, P6_y, 0>, P6_r}
         sphere {< 3, P6_y, 0>, P6_r}      sphere {< 7, P6_y, 0>, P6_r}
         texture {P6_t}
      }
   } ;

// The fifth row of beads (passes 3, 4 and 6):

#declare Beads_row5 =
   union {
      union { // pass 3
         sphere {<-7, P3_y, 0>, P3_r}      sphere {< 1, P3_y, 0>, P3_r}
         texture {P3_t}
      }
      union { // pass 4
         sphere {<-3, P4_y, 0>, P4_r}      sphere {< 5, P4_y, 0>, P4_r}
         texture {P4_t}
      }
      union { // pass 6
         sphere {<-5, P6_y, 0>, P6_r}      sphere {<-1, P6_y, 0>, P6_r}
         sphere {< 3, P6_y, 0>, P6_r}      sphere {< 7, P6_y, 0>, P6_r}
         texture {P6_t}
      }
   } ;

// Now merge rows 1 - 8:

#declare Beads =
   union {
      object {Beads_row1 translate  7*z}
      object {Beads_row2 translate  5*z}
      object {Beads_row3 translate  3*z}
      object {Beads_row2 translate  1*z}
      object {Beads_row5 translate -1*z}
      object {Beads_row2 translate -3*z}
      object {Beads_row3 translate -5*z}
      object {Beads_row2 translate -7*z}
   } ;

// Declare the word "PNG":

#declare PNG_Word =
   height_field {
      //gif "pngword5c.gif"
      gif "pngword6.gif"	// GRR 20000813:  white7j:  high-res heightmap
      smooth
      water_level 0.001
      translate <-0.49, -3.0, -0.05>  /* +x: right   +y: out   +z: up (top) */
      /* scale <1408/365, 1, 1> */
      /* scale <914/265, 1, 1> */
      scale <1259/368, 1, 1>
/*
      texture {Mirror pigment {Silver}}
 */
      // GRR 20010828:  black7v:  changed transparency to 0.85
      // GRR 20010828:  trunc7v:  changed back to black7d material
      // GRR 20010903:  white810:  changed back to white7u material
      // GRR 20020119:  black813:  reduced R,G,B by 0.1 each
      // GRR 20020119:  black814:  changed transparency to 0.85 again
      // GRR 20200802:  black822:  commented out iridescence: too busy for dark backgrounds
      texture {
         //pigment {color rgb <0.5, 0.55, 0.6> filter 0.925}	// white7u
         //pigment {color rgb <0.9, 0.95, 1.0> filter 0.925}	// black7d
         //pigment {color rgb <0.8, 0.85, 0.9> filter 0.925}	// black813
         //pigment {color rgb <0.8, 0.85, 0.9> filter 0.85}	// black814
         pigment {color rgb <0.5, 0.55, 0.6> filter 0.85}	// black816

//         finish {
//            Shiny
//            //ambient 0.7 	// 805
//            ambient 0.3		// 807
//            //diffuse 0.2 	// 805
//            diffuse 0.1		// 806
//            reflection 0.70	// 803
//            specular 0.75	// 803
//            roughness 0.001	// 803
//            irid {		// 805
//               //0.35		// 805
//               //0.15		// 808
//               0.22		// 809
//               thickness .5
//               turbulence .5
//            }
//         }

         finish {
            Shiny
            ambient 0
            /* diffuse 0.2 */
            diffuse 0.2		// white812, black813
            reflection 0.3
//          irid {		// black815
//             0.22		// black815
//             thickness .5
//             turbulence .5
//          }
         }
      }
//    // black820-823:  tried hollow + media particles for "emissive glow," but
//    // didn't really illuminate anything externally and instead overrode true
//    // colors of things seen _though_ the text with pure blue => gone in 824+
//    hollow			// black820:  required for media particles
//    interior {		// 801
//       ior 2.0		// black818:  halfway to diamond (2.4)
//       media {		// black820:  first test of emission; trying for glowing text
//          intervals 1
//          samples 1,1
//          emission <0.05, 0.05, 0.2>	// black821:  1,1,1 saturated balls seen through "PNG" => tone it way down and shift toward blue emission
//       }
//    }
      interior {		// black825:  oops, didn't mean to nuke entire interior block...MUST have index of refraction!
         ior 2.0
      }
   } ;

// GRR 20010828:  trunc7v:  commented out balls to fix lighting on text
// GRR 20010828:  black7z:  reenabled balls
object {
   object {Beads}
   rotate <-70, 0, 0>
   photons{			// black818
      target
      reflection on
      refraction on
      collect off
   }
}

// GRR 20010902:  black801:  commented out "PNG" to fix pass 7 transparency
// GRR 20010902:  black810:  reenabled "PNG"
object {
   PNG_Word
   scale <5.8, 1.2, 5.8>
   rotate -70*x
   translate <0, -1.5, -7.5>
   photons{collect off}		// black818
}

// This is our "sky sphere" for mirror surfaces:
// object {
//    sphere {<0, 0, 0>, 50 texture {Blue_Sky2}}   these clouds suck
// }

// --- END ---
